@@ -1,9 +1,10 @@
 from django_filters.rest_framework import DjangoFilterBackend
-from functions import get_prop
 from rest_framework import filters, status, viewsets
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 
+from novadata_utils.functions import get_prop
+
 
 class NovadataModelViewSet(viewsets.ModelViewSet):
     permission_classes = [
